@@ -1,5 +1,5 @@
 
-def pipje():
+def showpip():
     from PIL import Image, ImageTk
     from urllib.request import urlopen
     import tkinter as tk
